@@ -1,20 +1,8 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
- * Copyright 2015 Sebastian Kügler <sebas@kde.org>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Sebastian Kügler <sebas@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -27,22 +15,22 @@
 #ifndef KSCREEN_BACKENDMANAGER_H
 #define KSCREEN_BACKENDMANAGER_H
 
+#include <QDBusServiceWatcher>
+#include <QEventLoop>
+#include <QFileInfoList>
 #include <QObject>
 #include <QPluginLoader>
 #include <QProcess>
-#include <QDBusServiceWatcher>
-#include <QFileInfoList>
 #include <QTimer>
-#include <QEventLoop>
 
-#include "types.h"
 #include "kscreen_export.h"
+#include "types.h"
 
 class QDBusPendingCallWatcher;
 class OrgKdeKscreenBackendInterface;
 
-namespace KScreen {
-
+namespace KScreen
+{
 class AbstractBackend;
 
 class KSCREEN_EXPORT BackendManager : public QObject
@@ -52,7 +40,7 @@ class KSCREEN_EXPORT BackendManager : public QObject
 public:
     enum Method {
         InProcess,
-        OutOfProcess
+        OutOfProcess,
     };
 
     static BackendManager *instance();
@@ -93,9 +81,7 @@ public:
      * @return a pointer to the backend loaded from the plugin
      * @since 5.6
      */
-    static KScreen::AbstractBackend *loadBackendPlugin(QPluginLoader *loader,
-                                                 const QString &name,
-                                                 const QVariantMap &arguments);
+    static KScreen::AbstractBackend *loadBackendPlugin(QPluginLoader *loader, const QString &name, const QVariantMap &arguments);
 
     KScreen::AbstractBackend *loadBackendInProcess(const QString &name);
 
@@ -112,8 +98,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void emitBackendReady();
 
-    void startBackend(const QString &backend = QString(),
-                      const QVariantMap &arguments = QVariantMap());
+    void startBackend(const QString &backend = QString(), const QVariantMap &arguments = QVariantMap());
     void onBackendRequestDone(QDBusPendingCallWatcher *watcher);
 
     void backendServiceUnregistered(const QString &serviceName);
@@ -147,7 +132,7 @@ private:
 
     // For in-process operation
     QPluginLoader *mLoader;
-    QPair<KScreen::AbstractBackend*, QVariantMap> m_inProcessBackend;
+    QPair<KScreen::AbstractBackend *, QVariantMap> m_inProcessBackend;
 
     Method mMethod;
 };
